@@ -4,7 +4,7 @@ package HTML::Element::AbsoluteXPath;
 
 # ABSTRACT: Add absolute XPath support to HTML::Element
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '1.0'; # VERSION
 
 use HTML::Element 5.03;
 
@@ -35,7 +35,7 @@ sub HTML::Element::abs_xpath{
         }   
 
         my @attrs;
-        foreach (keys %filters){
+        foreach (sort keys %filters){
             next if $_ eq '_tag';
             my $v = $filters{$_};
             my $pat = "\@$_='$v'";
@@ -61,13 +61,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::Element::AbsoluteXPath - Add absolute XPath support to HTML::Element
 
 =head1 VERSION
 
-version 0.02
+version 1.0
 
 =head1 DESCRIPTION
 
